pub fn init()Expand description
Initialize a global tracing logger.
- The logger will print enabled
tracingevents and spans to stderr. - You can change the log level or module filtering with an appropriate
RUST_LOGenv var set. Read more about the syntax here: https://docs.rs/tracing-subscriber/latest/tracing_subscriber/filter/struct.EnvFilter.html
Panics if a logger is already initialized. This will fail if used in tests, since multiple test threads will compete to set the global logger.