init

Function init 

pub fn init()
Initialize a global tracing logger.

Panics if a logger is already initialized. This will fail if used in tests, since multiple test threads will compete to set the global logger.